The aivm Module
==================

.. warning::

   This project was written with GPT-5.3 Codex and is still being evaluated
   for correctness and safety. It is for experimental use only.



|Pypi| |PypiDownloads| |ReadTheDocs|



+---------------+------------------------------------------+
| Read the Docs | http://aivm.readthedocs.io/en/latest/ |
+---------------+------------------------------------------+
| Pypi          | https://pypi.org/project/aivm         |
+---------------+------------------------------------------+



.. |Pypi| image:: https://img.shields.io/pypi/v/aivm.svg
    :target: https://pypi.python.org/pypi/aivm

.. |PypiDownloads| image:: https://img.shields.io/pypi/dm/aivm.svg
    :target: https://pypistats.org/packages/aivm

.. |ReadTheDocs| image:: https://readthedocs.org/projects/aivm/badge/?version=latest
    :target: http://aivm.readthedocs.io/en/latest/
